#!/usr/local/bin/perl

######################################################################
# PROGRAM: Minas::BigMac
#
# Copyright (C), 2002
# Bridget McInnes,       bthomson@d.umn.edu
# Deodatta Y Bhoite,     bhoi0001@d.umn.edu
# Kailash Aurangabadkar, aura0011@d.umn.edu
# Nitin Agarwal,         agar0054@d.umn.edu
# Yanhua Li,             lixx0333@d.umn.edu
#
# University of Minnesota, Duluth
#
# USAGE:
#          %perl interface.pl
#
# The program allows the user to access the MacQuarie's machine 
# readable dictionary in an easy menu driven way. This program 
# also gives examples on how to use the Minas::BigMac module.
#
#######################################################################

 use BigMac;

       # instantiate the class
       my $bm = Minas::BigMac->new;
       my $ch = 1;
       #set locations for the dictionary and thesaurus
       print "\nEnter path of dictionary: ";
       $dictpath=<>;
       chomp($dictpath);
       print "\nEnter path of thesaurus: ";
       $thespath=<>;
       chomp($thespath);
       print "\n\nPlease be patient. This will take some time...\n\n";
       $bm->setDictionaryLocation($dictpath);
       $bm->setThesaurusLocation($thespath);
   while($ch!=0)
   {
       system("clear");
       # select a particular word
       $index=0;
       print "\t***Minas BigMac Menu***\n";
       print "-"x50;
       print "\n\n";
       print "1. Get Definition of a particular word\n";
       print "2. Get Pronunciation of a particular word\n";
       print "3. Get Idiomatic phrases of a particular word\n";
       print "4. Get Etymology of a particular word\n";
       print "5. Get Synonyms of a particular word\n";
       print "6. Search words whose definitions have a list of specified words\n";
       print "0. Exit\n\n\n";
       print "Enter choice:-";
       $ch=<>;
       chomp($ch);
       # code for getting definitions
       if($ch == 1)
       {
	   $file="";
       		print "\nEnter the word:-";
       		$word=<>;
		chomp($word);
	   print "Do you want the output to file(y/n)? ";
	   $choice=<>;
	   chomp($choice);
	   if($choice eq "y"){
	       print "Enter filename: ";
	       $file=<>;
	       chomp($file);
	       open(OUT,">$file") or die "cannot open file for output\n";
       		@defs = $bm->getDefinitions($word);
       		foreach $def (@defs){
           		print OUT "$def\n";
       		}
	       close(OUT);
	   }else{
	       $index=0;
       		@defs = $bm->getDefinitions($word);
       		print "\nDefinitions...\n";
       		foreach $def (@defs){
           		print "\t".++$index.". $def\n";
       		}
	    }
       }

       # code for getting pronunciations
       if($ch == 2)
       {
       		print "\nEnter the word:-";
       		$word=<>;
		chomp($word);
	   print "Do you want the output to file(y/n)? ";
	   $choice=<>;
	   chomp($choice);
	   if($choice eq "y"){
	       print "Enter filename: ";
	       $file=<>;
	       chomp($file);
	       open(OUT,">$file") or die "cannot open file for output\n";
       		%prons = $bm->getPronunciations($word);
       		foreach $prn (keys %prons){
           		print OUT "$prn\n";
       		}
	       close(OUT);
	   }else{
	       $index=0;
       		%prons = $bm->getPronunciations($word);
       		print "\nPronunciation...\n";
       		foreach $prn (keys %prons){
           		print "\t".++$index.". $prn\n";
       		}
	    }
	}

       # code fpr getting idiomatic phrases
       if($ch == 3)
       {
       		print "\nEnter the word:-";
       		$word=<>;
		chomp($word);
	   print "Do you want the output to file(y/n)? ";
	   $choice=<>;
	   chomp($choice);
	   if($choice eq "y"){
	       print "Enter filename: ";
	       $file=<>;
	       chomp($file);
	       open(OUT,">$file") or die "cannot open file for output\n";
                @ips = $bm->getIdiomaticPhrases($word);
       		foreach $ip (@ips){
           		print OUT "$ip\n";
		}
	       close(OUT);
	   }else{
	       $index=0;
                @ips = $bm->getIdiomaticPhrases($word);
       		print "\nIdiomatic Phrases...\n";
       		foreach $ip (@ips){
           		print "\t".++$index.". $ip\n";
       		}
	    }
       }
       # code for getting etymology
       if($ch == 4)
       {
       		print "\nEnter the word:-";
       		$word=<>;
		chomp($word);
		print "\nEnter expression (.* for all, English for english roots):-";
		$expr=<>;
		chomp($expr);
	   print "Do you want the output to file(y/n)? ";
	   $choice=<>;
	   chomp($choice);
	   if($choice eq "y"){
	       print "Enter filename: ";
	       $file=<>;
	       chomp($file);
	       open(OUT,">$file") or die "cannot open file for output\n";
  		%etys = $bm->getEtymology($word,$expr);
       		foreach $ety (keys %etys){
           		print OUT "$ety -> $etys{$ety}\n";
       		}
	       close(OUT);
	   }else{
                # word and regular expression for language for which etymology is to be found
	       $index=0;
  		%etys = $bm->getEtymology($word,$expr);
       		print "\nEtymology...\n";
       		foreach $ety (keys %etys){
           		print "\t".++$index.". $ety -> $etys{$ety}\n";
       		}
	    }
       }
       # code for getting synonyms
       if($ch == 5)
       {
       		print "\nEnter the word:-";
       		$word=<>;
		chomp($word);
	   print "Do you want the output to file(y/n)? ";
	   $choice=<>;
	   chomp($choice);
	   if($choice eq "y"){
	       print "Enter filename: ";
	       $file=<>;
	       chomp($file);
	       open(OUT,">$file") or die "cannot open file for output\n";
		%syns = $bm->getSynonyms($word);
		foreach $key (keys %syns){
		    print OUT "$key: ";
		    foreach $thes (@{$syns{$key}}){
			print OUT "$thes; ";
		    }
		    print OUT "\n";
		}
	       close(OUT);
	   }else{
		%syns = $bm->getSynonyms($word);
		print "\nSynonyms...\n";
		foreach $key (keys %syns){
		    print "$key: ";
		    foreach $thes (@{$syns{$key}}){
			print "$thes; ";
		    }
		    print "\n";
		}
	    }
       }
       if($ch == 6){
	   print "\nEnter list of comma-separated words to find in definitions:-";
	   $expr=<>;
	   chomp($expr);
#	   $bm->getWords($expr);
	   print "Do you want the output to file(y/n)? ";
	   $choice=<>;
	   chomp($choice);
	   if($choice eq "y"){
	       print "Enter filename: ";
	       $file=<>;
	       chomp($file);
	       open(OUT,">$file") or die "cannot open file for output\n";
	       %defs = $bm->getWords($expr);
	       foreach $key (keys %defs){
		   print OUT "$key : $defs{$key}\n";
	       }
	       close(OUT);
	   }else{
	       %defs = $bm->getWords($expr);
	       print "\nDefinitions containing $expr...\n";
	       print "Format of output=> word; pos; thes : definition\n";
	       $index=1;
	       foreach $key (keys %defs){
		   print "($index) $key : $defs{$key}\n";
		   $index++;
	       }
	   }
       }
       print "\n\n\n\nPress return to continue...";
       $word=<>;
    }
